@@ -1,4 +1,5 @@
 import locale
+import pkg_resources
 import gettext
 
 def get_default_locale_encoding():
@@ -7,6 +8,7 @@ def get_default_locale_encoding():
 
 def get_default_locale_message_handler():
     default, encoding = get_default_locale_encoding()
-    lang = gettext.translation('inclusivewriting', localedir='locales', languages=[default])
+    localesdir = pkg_resources.resource_filename('inclusivewriting', 'locales')
+    lang = gettext.translation('inclusivewriting', localedir=localesdir, languages=[default])
     lang.install()
     return lang.gettext
